@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,12 +22,10 @@
 FilterActionDeleteTest::FilterActionDeleteTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FilterActionDeleteTest::~FilterActionDeleteTest()
 {
-
 }
 
 void FilterActionDeleteTest::shouldHaveDefaultValue()
@@ -67,7 +65,7 @@ void FilterActionDeleteTest::shouldDeleteItem()
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("");
+    filter.argsFromString(QString());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::GoOn);
     QCOMPARE(context.needsPayloadStore(), false);
     QCOMPARE(context.deleteItem(), true);
