@@ -165,7 +165,8 @@ MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopI
                                         .arg(i18n("A problem was found while applying this action."));
                 FilterLog::instance()->add(logText, FilterLog::AppliedAction);
             }
-        default:
+        case FilterAction::GoOn:
+        case FilterAction::ErrorNeedComplete:
             break;
         }
     }
@@ -271,7 +272,7 @@ SearchRule::RequiredPart MailFilter::requiredPart(const QString &id) const
     }
 
     if (pattern()) {
-        requiredPart = qMax(requiredPart, (int)pattern()->requiredPart());    // no pattern means always matches?
+        requiredPart = qMax(requiredPart, static_cast<int>(pattern()->requiredPart()));    // no pattern means always matches?
     }
 
     int requiredPartByActions = SearchRule::Envelope;
@@ -418,13 +419,13 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
         bApplyOnAllFolders = false;
         mApplicability = ButImap;
     } else {
-        bApplyBeforeOutbound = bool(sets.contains(QStringLiteral("before-send-mail")));
-        bApplyOnInbound = bool(sets.contains(QStringLiteral("check-mail")));
-        bApplyOnOutbound = bool(sets.contains(QStringLiteral("send-mail")));
-        bApplyOnExplicit = bool(sets.contains(QStringLiteral("manual-filtering")));
-        bApplyOnAllFolders = bool(sets.contains(QStringLiteral("all-folders")));
-        mApplicability = (AccountType)config.readEntry(
-            "Applicability", (int)ButImap);
+        bApplyBeforeOutbound = bool(sets.contains(QLatin1String("before-send-mail")));
+        bApplyOnInbound = bool(sets.contains(QLatin1String("check-mail")));
+        bApplyOnOutbound = bool(sets.contains(QLatin1String("send-mail")));
+        bApplyOnExplicit = bool(sets.contains(QLatin1String("manual-filtering")));
+        bApplyOnAllFolders = bool(sets.contains(QLatin1String("all-folders")));
+        mApplicability = static_cast<AccountType>(config.readEntry(
+                                                      "Applicability", static_cast<int>(ButImap)));
     }
 
     bStopProcessingHere = config.readEntry("StopProcessingHere", true);
@@ -500,9 +501,9 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
     return needUpdate;
 }
 
-void MailFilter::generateSieveScript(QStringList &requires, QString &code)
+void MailFilter::generateSieveScript(QStringList &requiresModules, QString &code)
 {
-    mPattern.generateSieveScript(requires, code);
+    mPattern.generateSieveScript(requiresModules, code);
 
     QList<FilterAction *>::const_iterator it;
     QList<FilterAction *>::const_iterator end(mActions.constEnd());
@@ -522,8 +523,8 @@ void MailFilter::generateSieveScript(QStringList &requires, QString &code)
         code += indentationStr + (*it)->sieveCode();
         const QStringList lstRequires = (*it)->sieveRequires();
         for (const QString &str : lstRequires) {
-            if (!requires.contains(str)) {
-                requires.append(str);
+            if (!requiresModules.contains(str)) {
+                requiresModules.append(str);
             }
         }
     }
@@ -540,19 +541,19 @@ void MailFilter::writeConfig(KConfigGroup &config, bool exportFilter) const
 
     QStringList sets;
     if (bApplyOnInbound) {
-        sets.append(QStringLiteral("check-mail"));
+        sets.append(QLatin1String("check-mail"));
     }
     if (bApplyBeforeOutbound) {
-        sets.append(QStringLiteral("before-send-mail"));
+        sets.append(QLatin1String("before-send-mail"));
     }
     if (bApplyOnOutbound) {
-        sets.append(QStringLiteral("send-mail"));
+        sets.append(QLatin1String("send-mail"));
     }
     if (bApplyOnExplicit) {
-        sets.append(QStringLiteral("manual-filtering"));
+        sets.append(QLatin1String("manual-filtering"));
     }
     if (bApplyOnAllFolders) {
-        sets.append(QStringLiteral("all-folders"));
+        sets.append(QLatin1String("all-folders"));
     }
     config.writeEntry("apply-on", sets);
 
@@ -567,7 +568,7 @@ void MailFilter::writeConfig(KConfigGroup &config, bool exportFilter) const
         config.writeEntry("Icon", mIcon);
     }
     config.writeEntry("AutomaticName", bAutoNaming);
-    config.writeEntry("Applicability", (int)mApplicability);
+    config.writeEntry("Applicability", static_cast<int>(mApplicability));
     config.writeEntry("Enabled", bEnabled);
     QString key;
     int i;
@@ -646,8 +647,8 @@ const QString MailFilter::asString() const
 {
     QString result;
 
-    result += "Filter name: " + name() + " (" + mIdentifier  + ")\n";
-    result += mPattern.asString() + '\n';
+    result += QStringLiteral("Filter name: ") + name() + QStringLiteral(" (") + mIdentifier  + QStringLiteral(")\n");
+    result += mPattern.asString() + QLatin1Char('\n');
 
     result += QString("Filter is %1\n").arg(bEnabled ? QStringLiteral("enabled") : QStringLiteral("disabled"));
 
