@@ -37,9 +37,6 @@ public:
 protected:
     Akonadi::Collection parentCollection(const QModelIndex &index) const override;
 
-private:
-    class FavoriteCollectionOrderProxyModelPrivate;
-    FavoriteCollectionOrderProxyModelPrivate *const d;
 };
 }
 
