@@ -1,9 +1,10 @@
 /*
   Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,21 +43,21 @@ public:
 
     void recordTagSettings(MailCommon::Tag::Ptr tag);
 
-    KLineEdit *tagNameLineEdit() const;
-    QCheckBox *textColorCheck() const;
-    QCheckBox *textFontCheck() const;
-    QCheckBox *backgroundColorCheck() const;
-    QCheckBox *inToolBarCheck() const;
+    Q_REQUIRED_RESULT KLineEdit *tagNameLineEdit() const;
+    Q_REQUIRED_RESULT QCheckBox *textColorCheck() const;
+    Q_REQUIRED_RESULT QCheckBox *textFontCheck() const;
+    Q_REQUIRED_RESULT QCheckBox *backgroundColorCheck() const;
+    Q_REQUIRED_RESULT QCheckBox *inToolBarCheck() const;
 
-    KColorCombo *textColorCombo() const;
-    KColorCombo *backgroundColorCombo() const;
+    Q_REQUIRED_RESULT KColorCombo *textColorCombo() const;
+    Q_REQUIRED_RESULT KColorCombo *backgroundColorCombo() const;
 
-    QCheckBox *textBoldCheck() const;
-    QCheckBox *textItalicCheck() const;
+    Q_REQUIRED_RESULT QCheckBox *textBoldCheck() const;
+    Q_REQUIRED_RESULT QCheckBox *textItalicCheck() const;
 
-    KIconButton *iconButton() const;
+    Q_REQUIRED_RESULT KIconButton *iconButton() const;
 
-    KKeySequenceWidget *keySequenceWidget() const;
+    Q_REQUIRED_RESULT KKeySequenceWidget *keySequenceWidget() const;
 
     void setTagTextColor(const QColor &color);
     void setTagBackgroundColor(const QColor &color);
